<?php

namespace edu\wisc\doit;

/**
 * FederatedPreauthUserDetailsProvider provides an application with a {@link UWUserDetails} from Shibboleth attributes.
 * The attributes use the keys as defined by UW System, which are distinct from those used specifically by UWMSN.
 */
class FederatedPreauthUserDetailsProvider implements UserDetailsProvider
{

    /** @var bool */
    private $httpHeaders;

    /**
     * FederatedPreauthUserDetailsProvider constructor.
     *
     * @param bool $http flag indicating if Shibboleth attributes are forwarded as HTTP headers
     */
    public function __construct($http = false)
    {
        $this->httpHeaders = $http;
    }

    /**
     * {@inheritdoc}
     */
    public function loadUser()
    {
        // Return null if no Shib session is found
        if (empty(getenv(FederatedPreauthUserDetailsProvider::SHIB_SESSION_ID)) &&
            empty(getenv(FederatedPreauthUserDetailsProvider::SHIB_SESSION_ID_HTTP))) {
            return null;
        }

        if ($this->httpHeaders) {
            $userDetails = new UWUserDetails(
                getenv($this->mapAttribute(UserDetailsProvider::FED_EPPN)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_SPVI)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_FULLNAME)),
                getenv($this->mapAttribute(UserDetailsProvider::UDDS)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_EMAIL)),
                getenv($this->mapAttribute(UserDetailsProvider::SOURCE)),
                getenv($this->mapAttribute(UserDetailsProvider::ISIS_EMPLID)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_FIRST_NAME)),
                getenv($this->mapAttribute(UserDetailsProvider::FED_LAST_NAME))
            );
        } else {
            $userDetails = new UWUserDetails(
                getenv(UserDetailsProvider::FED_EPPN),
                getenv(UserDetailsProvider::FED_SPVI),
                getenv(UserDetailsProvider::FED_FULLNAME),
                getenv(UserDetailsProvider::UDDS),
                getenv(UserDetailsProvider::FED_EMAIL),
                getenv(UserDetailsProvider::SOURCE),
                getenv(UserDetailsProvider::ISIS_EMPLID),
                getenv(UserDetailsProvider::FED_FIRST_NAME),
                getenv(UserDetailsProvider::FED_LAST_NAME)
            );
        }

        return $userDetails;
    }

    /**
     * Map a Shibboleth attribute to its associated HTTP header name.
     *
     * @param string $attribute attribute to map
     * @return string Shibboleth attribute name mapped to its equivalent HTTP header name
     */
    private function mapAttribute($attribute)
    {
        return 'HTTP_' . strtoupper($attribute);
    }

}
