<?php

namespace edu\wisc\doit;

/**
 * LocalUserDetailsProvider provides a developer with a {@link UWUserDetails} suitable for use in local development.
 */
class LocalUserDetailsProvider implements UserDetailsProvider
{

    /** @var string */
    private $filePath;

    /**
     * LocalUserDetailsProvider constructor.
     *
     * @param $filePath path to JSON file defining a local user.
     */
    public function __construct($filePath)
    {
        $this->filePath = $filePath;
    }

    /**
     * {@inheritdoc}
     */
    public function loadUser()
    {
        $jsonString = file_get_contents($this->filePath);
        if ($jsonString === false) {
            return null;
        }

        $attributes = json_decode($jsonString, true);

        return new UWUserDetails(
            $attributes[UserDetailsProvider::FED_EPPN],
            $attributes[UserDetailsProvider::FED_SPVI],
            $attributes[UserDetailsProvider::FED_FULLNAME],
            $attributes[UserDetailsProvider::UDDS],
            $attributes[UserDetailsProvider::FED_EMAIL],
            $attributes[UserDetailsProvider::SOURCE],
            $attributes[UserDetailsProvider::ISIS_EMPLID],
            $attributes[UserDetailsProvider::FED_FIRST_NAME],
            $attributes[UserDetailsProvider::FED_LAST_NAME]
        );
    }

    /**
     * Get the path of the local user JSON file.
     *
     * @return string
     */
    public function getFilePath()
    {
        return $this->filePath;
    }

    /**
     * Set the path of the local user JSON file.
     * @param $filePath
     */
    public function setFilePath($filePath)
    {
        $this->filePath = $filePath;
    }

}