<?php

namespace edu\wisc\doit;

/**
 * Tests for {@link FederatedPreauthUserDetailsProvider}.
 */
class FederatedPreauthUserDetailsProviderTest extends \PHPUnit_Framework_TestCase
{

    /** @var UserDetailsProvider */
    private $userProvider;

    /**
     * Populate putenv with Shib attributes to simulate a logged in user
     */
    protected function setUp()
    {
        parent::setUp();
        $jsonString = file_get_contents(__DIR__ . "/../../../resources/testuser.json");
        if ($jsonString === false) {
            return null;
        }

        $attributes = json_decode($jsonString, true);
        putenv(UserDetailsProvider::FED_EPPN . '=' . $attributes[UserDetailsProvider::FED_EPPN]);
        putenv(UserDetailsProvider::FED_SPVI . '=' . $attributes[UserDetailsProvider::FED_SPVI]);
        putenv(UserDetailsProvider::FED_FULLNAME . '=' . $attributes[UserDetailsProvider::FED_FULLNAME]);
        putenv(UserDetailsProvider::FED_FIRST_NAME . '=' . $attributes[UserDetailsProvider::FED_FIRST_NAME]);
        putenv(UserDetailsProvider::FED_LAST_NAME . '=' . $attributes[UserDetailsProvider::FED_LAST_NAME]);
        putenv(UserDetailsProvider::UDDS . '=' . implode(",", $attributes[UserDetailsProvider::UDDS]));
        putenv(UserDetailsProvider::FED_EMAIL . '=' . $attributes[UserDetailsProvider::FED_EMAIL]);
        putenv(UserDetailsProvider::SOURCE . '=' . $attributes[UserDetailsProvider::SOURCE]);
        putenv(UserDetailsProvider::ISIS_EMPLID . '=' . $attributes[UserDetailsProvider::ISIS_EMPLID]);
        putenv(UserDetailsProvider::SHIB_SESSION_ID  . '=' . $attributes[UserDetailsProvider::SHIB_SESSION_ID]);
    }

    public function testLoadUser() {
        $this->userProvider = new FederatedPreauthUserDetailsProvider();
        $user = $this->userProvider->loadUser();
        $this->assertNotNull($user);
        $this->assertEquals("bbadger@wisc.edu", $user->getEppn());
        $this->assertEquals("UW123A456", $user->getPvi());
        $this->assertEquals("BUCKINGHAM BADGER", $user->getFullName());
        $this->assertEquals("bucky.badger@wisc.edu", $user->getEmailAddress());
        $this->assertEquals("a_source", $user->getSource());
        $this->assertEquals("123456789", $user->getIsisEmplid());
        $this->assertEquals("BUCKINGHAM", $user->getFirstName());
        $this->assertEquals("BADGER", $user->getLastName());
    }

    public function testLoadUserWithNoEPPN() {
        $this->userProvider = new FederatedPreauthUserDetailsProvider();
        // Clear Shib session ID to simulate no session
        putenv(UserDetailsProvider::SHIB_SESSION_ID);
        $user = $this->userProvider->loadUser();
        $this->assertNull($user);
    }

}
